@@ -1,6 +1,7 @@
 from celery import shared_task
 from django.apps import AppConfig
 
+from basxbread.utils import get_all_subclasses
 from basxbread.utils.celery import RepeatedTask
 
 from . import settings
@@ -18,7 +19,7 @@ class WorkflowsConfig(AppConfig):
 def update_workflows():
     from .models import WorkflowBase
 
-    for cls in WorkflowBase.__subclasses__():
+    for cls in get_all_subclasses(WorkflowBase):
         for workflow in cls.objects.filter(
             cancelled__isnull=True, completed__isnull=True
         ):
